@@ -4,8 +4,9 @@ use warnings;
 
 package Kavorka::TraitFor::Parameter::doc;
 
-our $VERSION = '0.1104'; # VERSION
+our $VERSION = '0.1105';
 # ABSTRACT: Document method parameters in the signature
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
 
 use Moo::Role;
 
@@ -23,22 +24,19 @@ Kavorka::TraitFor::Parameter::doc - Document method parameters in the signature
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Kavorka-TraitFor-Parameter-doc"><img src="https://api.travis-ci.org/Csson/p5-Kavorka-TraitFor-Parameter-doc.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-100.0%-brightgreen.svg" alt="coverage 100.0%" /></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.14+-blue.svg" alt="Requires Perl 5.14+" />
+<img src="https://img.shields.io/badge/coverage-100.0%25-brightgreen.svg" alt="coverage 100.0%" />
+<a href="https://github.com/Csson/p5-Kavorka-TraitFor-Parameter-doc/actions?query=workflow%3Amakefile-test"><img src="https://img.shields.io/github/workflow/status/Csson/p5-Kavorka-TraitFor-Parameter-doc/makefile-test" alt="Build status at Github" /></a>
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Kavorka-TraitFor-Parameter-doc.svg?branch=master)](https://travis-ci.org/Csson/p5-Kavorka-TraitFor-Parameter-doc) ![coverage 100.0%](https://img.shields.io/badge/coverage-100.0%-brightgreen.svg)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.1104, released 2016-01-26.
+Version 0.1105, released 2021-02-28.
 
 =head1 SYNOPSIS
 
@@ -103,7 +101,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Erik Carlsson.
+This software is copyright (c) 2021 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
