@@ -4,8 +4,9 @@ use warnings;
 
 package Kavorka::TraitFor::ReturnType::doc;
 
-our $VERSION = '0.1104'; # VERSION
+our $VERSION = '0.1105';
 # ABSTRACT: Document return types in the signature
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
 
 use Moo::Role;
 
@@ -23,7 +24,7 @@ Kavorka::TraitFor::ReturnType::doc - Document return types in the signature
 
 =head1 VERSION
 
-Version 0.1104, released 2016-01-26.
+Version 0.1105, released 2021-02-28.
 
 =head1 SYNOPSIS
 
@@ -86,7 +87,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Erik Carlsson.
+This software is copyright (c) 2021 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
